@@ -20,19 +20,19 @@ if "OpenBabel_version" not in globals():
 logger = logging.getLogger("read_structure_step.read_structure")
 
 metadata = {
-    "CP": "constant pressure heat capacity",
-    "CPR": "reference.constant pressure heat capacity",
-    "D": "dipole moment",
-    "DR": "reference.dipole moment",
-    "H": "enthalpy of formation",
-    "HR": "reference.enthalpy of formation",
-    "S": "entropy",
-    "SR": "reference.entropy",
-    "I": "ionization energy",
-    "IE": "ionization energy",
-    "IA": "ionization energy",
-    "IR": "reference.ionization energy",
-    "GR": "reference.geometry",
+    "CP": "constant pressure heat capacity#experiment",
+    "CPR": "reference.constant pressure heat capacity#experiment",
+    "D": "dipole moment#experiment",
+    "DR": "dipole moment.reference#experiment",
+    "H": "enthalpy of formation#experiment",
+    "HR": "enthalpy of formation.reference#experiment",
+    "S": "entropy#experiment",
+    "SR": "entropy.reference#experiment",
+    "I": "ionization energy#experiment",
+    "IE": "ionization energy#experiment",
+    "IA": "ionization energy#experiment",
+    "IR": "ionization energy.reference#experiment",
+    "GR": "geometry.reference#experiment",
 }
 multiplicities = {
     "SINGLET": 1,
@@ -494,14 +494,14 @@ def load_mop(
     # Save keywords, description and any data encoded in the file to the database
     if save_data:
         properties = configuration.properties
-        if len("keywords") != 0:
-            key = "MOPAC.keywords"
+        if len(keywords) != 0:
+            key = "keywords#MOPAC"
             properties.add(
                 key, "str", description="The keywords for MOPAC", noerror=True
             )
             properties.put(key, " ".join(keywords))
         if len(description_lines) > 0:
-            key = "MOPAC.description"
+            key = "description#MOPAC"
             properties.add(
                 key,
                 "str",
@@ -510,7 +510,7 @@ def load_mop(
             )
             properties.put(key, "\n".join(description_lines))
         if energy is not None:
-            key = "MOPAC.reference energy"
+            key = "reference energy#MOPAC"
             properties.add(
                 key,
                 "float",
@@ -536,14 +536,32 @@ def load_mop(
                                 print()
                                 continue
                             keyword = metadata[keyword]
+                            if value == "":
+                                print(f"Value for {keyword} missing in MOPAC .mop file")
+                                continue
                             if "reference" in keyword:
-                                description = keyword.split(".")[1]
+                                description = keyword.split(".")[0]
                                 properties.add(
                                     keyword,
                                     "str",
                                     description=f"Reference for the {description}.",
                                     noerror=True,
                                 )
+                            elif "," in value:
+                                # value , stderr
+                                tmp = value.split(",")
+                                value = tmp[0].strip()
+                                stderr = tmp[1].strip()
+                                tmp = keyword.split("#")
+                                tmp[0] = tmp[0] + " stderr"
+                                new_keyword = "#".join(tmp)
+                                properties.add(
+                                    new_keyword,
+                                    "float",
+                                    description=f"stderr for the {keyword}.",
+                                    noerror=True,
+                                )
+                                properties.put(new_keyword, stderr)
                             properties.put(keyword, value)
                         except Exception as e:
                             print(f"{e}: {key}")
