@@ -22,6 +22,7 @@ import read_structure_step
 from .read import read
 import seamm
 from seamm_util import ureg, Q_  # noqa: F401
+from seamm_util import getParser
 import seamm_util.printing as printing
 from seamm_util.printing import FormattedText as __
 from .utils import guess_extension
@@ -69,6 +70,62 @@ class ReadStructure(seamm.Node):
         """The git version of this module."""
         return read_structure_step.__git_revision__
 
+    def create_parser(self):
+        """Setup the command-line / config file parser"""
+        # Need to mimic MOPAC step to find the MOPAC executable
+        parser_name = "mopac-step"
+        print(f"Parser {parser_name}, {self.step_type=}")
+        parser = getParser()
+
+        # Remember if the parser exists ... this type of step may have been
+        # found before
+        parser_exists = parser.exists(parser_name)
+        print(f"{parser_exists=}")
+
+        # Create the standard options, e.g. log-level
+        result = super().create_parser(name=parser_name)
+
+        if parser_exists:
+            return result
+
+        # Options for Mopac
+        parser.add_argument(
+            parser_name,
+            "--mopac-exe",
+            default="MOPAC2016.exe",
+            help="the name of the MOPAC executable",
+        )
+
+        parser.add_argument(
+            parser_name,
+            "--mopac-path",
+            default="",
+            help="the path to the MOPAC executable",
+        )
+
+        parser.add_argument(
+            parser_name,
+            "--ncores",
+            default="default",
+            help="How many threads to use in MOPAC",
+        )
+
+        parser.add_argument(
+            parser_name,
+            "--mkl-num-threads",
+            default="default",
+            help="How many threads to use with MKL in MOPAC",
+        )
+
+        parser.add_argument(
+            parser_name,
+            "--max-atoms-to-print",
+            default=25,
+            help="Maximum number of atoms to print charges, etc.",
+        )
+
+        return result
+
     def description_text(self, P=None):
         """Create the text description of what this step will do.
         The dictionary of control values is passed in as P so that
@@ -102,7 +159,7 @@ class ReadStructure(seamm.Node):
                     path = PurePath(filename)
                     extension = path.suffix
                     if extension == ".gz":
-                        extension = path.stem.suffix
+                        extension = path.with_suffix("").suffix
 
         # Get the metadata for the format
         metadata = get_format_metadata(extension)
@@ -143,7 +200,7 @@ class ReadStructure(seamm.Node):
             else:
                 extension = path.suffix
                 if extension == ".gz":
-                    extension = path.stem.suffix
+                    extension = path.with_suffix("").suffix
 
             if extension == "":
                 extension = guess_extension(filename, use_file_name=False)
@@ -158,7 +215,7 @@ class ReadStructure(seamm.Node):
                 P, structure_handling=True
             )
 
-            read(
+            configurations = read(
                 filename,
                 configuration,
                 extension=extension,
@@ -180,31 +237,32 @@ class ReadStructure(seamm.Node):
             system, configuration = self.get_system_configuration(
                 P, structure_handling=False
             )
-            if configuration.periodicity == 3:
-                space_group = configuration.symmetry.group
-                if space_group == "":
-                    symmetry_info = ""
+            if len(configurations) == 1:
+                if configuration.periodicity == 3:
+                    space_group = configuration.symmetry.group
+                    if space_group == "":
+                        symmetry_info = ""
+                    else:
+                        symmetry_info = f" The space group is {space_group}."
+                    printer.important(
+                        __(
+                            "\n    Created a periodic structure with "
+                            f"{configuration.n_atoms} atoms. {symmetry_info}"
+                            f"\n           System name = {system.name}"
+                            f"\n    Configuration name = {configuration.name}",
+                            indent=4 * " ",
+                        )
+                    )
                 else:
-                    symmetry_info = f" The space group is {space_group}."
-                printer.important(
-                    __(
-                        "\n    Created a periodic structure with "
-                        f"{configuration.n_atoms} atoms. {symmetry_info}"
-                        f"\n           System name = {system.name}"
-                        f"\n    Configuration name = {configuration.name}",
-                        indent=4 * " ",
+                    printer.important(
+                        __(
+                            "\n    Created a molecular structure with "
+                            f"{configuration.n_atoms} atoms."
+                            f"\n           System name = {system.name}"
+                            f"\n    Configuration name = {configuration.name}",
+                            indent=4 * " ",
+                        )
                     )
-                )
-            else:
-                printer.important(
-                    __(
-                        "\n    Created a molecular structure with "
-                        f"{configuration.n_atoms} atoms."
-                        f"\n           System name = {system.name}"
-                        f"\n    Configuration name = {configuration.name}",
-                        indent=4 * " ",
-                    )
-                )
 
         printer.important("")
 
